4.5.2 (2023-12-18)
==================
👷 Bug fixes
-----------

- SMTP: don't override SMTP import by MockSMTP in testlib
- testlib: move devtools.testlib.MockSMTP and devtools.testlib.Email

4.5.1 (2023-12-11)
==================
👷 Bug fixes
-----------

- remove a typing import which break compatibility with python 3.7

4.5.0 (2023-12-08)
==================
🎉 New features
--------------

- display progressbar when importing data
- minor refactoring to export reverse indicator stuff

👷 Bug fixes
-----------

- content_negociation: add a restriction on request_method for "one_entity" and "one_entity_eid" routes (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/934)
- content_negociation: fix a typo in cubicweb.pyramid.rest_api.include_html condition (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/934)